@@ -204,14 +204,25 @@ ole_info_read_metabat (GsfInfileMSOle *ole, guint32 *bats, guint32 max,
 	guint8 const *bat, *end;
 
 	for (; metabat < metabat_end; metabat++) {
-		bat = ole_get_block (ole, *metabat, NULL);
-		if (bat == NULL)
-			return NULL;
-		end = bat + ole->info->bb.size;
-		for ( ; bat < end ; bat += BAT_INDEX_SIZE, bats++) {
-			*bats = GSF_LE_GET_GUINT32 (bat);
-			g_return_val_if_fail (*bats < max ||
-					      *bats >= BAT_MAGIC_METABAT, NULL);
+		if (*metabat != BAT_MAGIC_UNUSED) {
+			bat = ole_get_block (ole, *metabat, NULL);
+			if (bat == NULL)
+				return NULL;
+			end = bat + ole->info->bb.size;
+			for ( ; bat < end ; bat += BAT_INDEX_SIZE, bats++) {
+				*bats = GSF_LE_GET_GUINT32 (bat);
+				g_return_val_if_fail (*bats < max ||
+						      *bats >= BAT_MAGIC_METABAT, NULL);
+			}
+		} else {
+			/* Looks like something in the wild sometimes creates
+			 * 'unused' entries in the metabat.  Let's assume that
+			 * corresponds to lots of unused blocks
+			 * http://bugzilla.gnome.org/show_bug.cgi?id=336858 */
+			unsigned i = ole->info->bb.size / BAT_INDEX_SIZE;
+			g_print ("Ping!\n");
+			while (i-- > 0)
+				bats[i] = BAT_MAGIC_UNUSED;
 		}
 	}
 	return bats;
@@ -508,7 +519,8 @@ ole_init_info (GsfInfileMSOle *ole, GError **err)
 	 * 2) It makes no sense to have a block larger than 2^31 for now.
 	 *    Maybe relax this later, but not much.
 	 */
-	if (6 > bb_shift || bb_shift >= 31 || sb_shift > bb_shift) {
+	if (6 > bb_shift || bb_shift >= 31 || sb_shift > bb_shift ||
+	    (gsf_input_size (ole->input) >> bb_shift) < 1) {
 		if (err != NULL)
 			*err = g_error_new (gsf_input_error_id (), 0,
 				"Unreasonable block sizes");
