@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -552,9 +552,8 @@ gsf_infile_zip_seek (GsfInput *input, gsf_off_t offset, GSeekType whence)
 	}
 
 	if (zip->stream) {
-		zip->stream->next_in  = NULL;
-		zip->stream->avail_in = 0;
-		zip->stream->total_in = 0;
+		(void) inflateEnd (zip->stream);
+		memset (zip->stream, 0, sizeof (z_stream));
 	}
 
 	if (zip_child_init (zip, NULL)) {
@@ -837,13 +836,13 @@ GSF_CLASS (GsfInfileZip, gsf_infile_zip,
 
 /**
  * gsf_infile_zip_new :
- * @source : A base #GsfInput
- * @err   : A #GError, optionally %null
+ * @source: A base #GsfInput
+ * @err: A #GError, optionally %null
  *
  * Opens the root directory of a Zip file.
- * NOTE : adds a reference to @source
+ * <note>This adds a reference to @source.</note>
  *
- * Returns : the new zip file handler
+ * Returns: the new zip file handler
  **/
 GsfInfile *
 gsf_infile_zip_new (GsfInput *source, GError **err)
