@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -23,6 +23,7 @@
 #define GSF_INFILE_ZIP_H
 
 #include <gsf/gsf.h>
+#include <glib-object.h>
 
 G_BEGIN_DECLS
 
@@ -32,9 +33,8 @@ typedef struct _GsfInfileZip GsfInfileZip;
 #define GSF_INFILE_ZIP(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), GSF_INFILE_ZIP_TYPE, GsfInfileZip))
 #define GSF_IS_INFILE_ZIP(o)       (G_TYPE_CHECK_INSTANCE_TYPE ((o), GSF_INFILE_ZIP_TYPE))
 
-GType gsf_infile_zip_get_type (void);
-
-GsfInfileZip  *gsf_infile_zip_new	      (GsfInput *source, GError **err);
+GType	   gsf_infile_zip_get_type (void);
+GsfInfile *gsf_infile_zip_new      (GsfInput *source, GError **err);
 
 G_END_DECLS
 
