@@ -2,10 +2,10 @@
 /*
  * gsf-input-gzip.h: wrapper to uncompress gzipped input
  *
- * Copyright (C) 2002 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2004 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2.1 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,9 +13,9 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -32,9 +32,8 @@ G_BEGIN_DECLS
 
 typedef struct _GsfInputGZip GsfInputGZip;
 
-GType gsf_input_gzip_get_type (void);
-
-GsfInputGZip *gsf_input_gzip_new (GsfInput *source, GError **err);
+GType	  gsf_input_gzip_get_type (void);
+GsfInput *gsf_input_gzip_new	  (GsfInput *source, GError **err);
 
 G_END_DECLS
 
