@@ -35,8 +35,8 @@ typedef struct _GsfInputTextline GsfInputTextline;
 GType gsf_input_textline_get_type (void);
 
 GsfInput      *gsf_input_textline_new		(GsfInput *source);
-unsigned char *gsf_input_textline_ascii_gets	(GsfInputTextline *input);
-guint8	      *gsf_input_textline_utf8_gets	(GsfInputTextline *input);
+unsigned char *gsf_input_textline_ascii_gets	(GsfInputTextline *textline);
+guint8	      *gsf_input_textline_utf8_gets	(GsfInputTextline *textline);
 
 G_END_DECLS
 
