@@ -2,7 +2,7 @@
 /*
  * gsf-libxml.c :
  *
- * Copyright (C) 2002-2005 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2006 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2.1 of the GNU Lesser General Public
@@ -419,6 +419,7 @@ typedef struct {
 	GSList	 	 *ns_stack;
 	GHashTable	 *ns_prefixes;
 	GPtrArray	 *ns_by_id;
+	gboolean          initialized;
 	gint	  	  unknown_depth; /* handle recursive unknown tags */
 	gboolean	  from_unknown_handler;
 
@@ -602,18 +603,21 @@ gsf_xml_in_start_element (GsfXMLInInternal *state, xmlChar const *name, xmlChar
 
 	if (state->unknown_depth++ > 0)
 		return;
-	g_warning ("Unexpected element '%s' in state %s.", name, node_name (state->pub.node));
 
+	g_print ("Unexpected element '%s' in state : \n\t", name);
 	ptr = state->pub.node_stack = g_slist_reverse (state->pub.node_stack);
-	for (;ptr != NULL && ptr->next != NULL; ptr = ptr->next) {
+	if (ptr != NULL)	/* skip toplevel catch all */
+		ptr = ptr->next;
+	for (;ptr != NULL && ptr != NULL; ptr = ptr->next) {
 		node = ptr->data;
 		if (node != NULL) {
 /* FIXME FIXME FIXME if we really want this do we also want namespaces ? */
-			g_print ("%s", node_name (&node->pub));
-			if (ptr->next != NULL && ptr->next->data != NULL)
-				g_print (" -> ");
+			g_print ("%s -> ", node_name (&node->pub));
 		}
 	}
+	if (state->pub.node != NULL) {
+		g_print ("%s\n", node_name (state->pub.node));
+	}
 	state->pub.node_stack = g_slist_reverse (state->pub.node_stack);
 }
 
@@ -699,6 +703,11 @@ gsf_free_xmlinnsinstance (GsfXMLInNSInstance *inst)
 static void
 gsf_xml_in_start_document (GsfXMLInInternal *state)
 {
+	/*
+	 * This function will not be called when parsing an empty
+	 * document.
+	 */
+	state->initialized	= TRUE;
 	state->pub.node = &state->pub.doc->root_node->pub;
 	state->unknown_depth	= 0;
 	state->pub.node_stack	= NULL;
@@ -718,14 +727,16 @@ gsf_xml_in_end_document (GsfXMLInInternal *state)
 	g_string_free (state->pub.content, TRUE);
 	state->pub.content = NULL;
 
-	g_ptr_array_free (state->ns_by_id, TRUE);
-	state->ns_by_id = NULL;
+	if (state->initialized) {
+		g_ptr_array_free (state->ns_by_id, TRUE);
+		state->ns_by_id = NULL;
 
-	g_hash_table_destroy (state->ns_prefixes);
-	state->ns_prefixes = NULL;
+		g_hash_table_destroy (state->ns_prefixes);
+		state->ns_prefixes = NULL;
 
-	g_return_if_fail (state->pub.node == &state->pub.doc->root_node->pub);
-	g_return_if_fail (state->unknown_depth == 0);
+		g_return_if_fail (state->pub.node == &state->pub.doc->root_node->pub);
+		g_return_if_fail (state->unknown_depth == 0);
+	}
 }
 
 static void
@@ -867,7 +878,7 @@ gsf_xml_in_doc_new (GsfXMLInNode const *nodes, GsfXMLInNS const *ns)
 	doc->ns        = ns;
 	doc->ns_by_id  = g_ptr_array_new ();
 
-	/* Add namespaces to an idex */
+	/* Add namespaces to an index */
 	if (ns != NULL)
 		for (i = 0; ns[i].uri != NULL ; i++) {
 			if (ns[i].ns_id >= doc->ns_by_id->len)
@@ -1000,6 +1011,7 @@ gsf_xml_in_doc_parse (GsfXMLInDoc *doc, GsfInput *input, gpointer user_state)
 
 	g_return_val_if_fail (doc != NULL, FALSE);
 
+	state.initialized = FALSE;
 	ctxt = gsf_xml_parser_context_full (input, &gsfXMLInParser, &state);
 	if (ctxt == NULL)
 		return FALSE;
@@ -1030,12 +1042,17 @@ gsf_xml_in_check_ns (GsfXMLIn const *xin, char const *str, unsigned int ns_id)
 {
 	GsfXMLInInternal const *state = (GsfXMLInInternal const *)xin;
 	GsfXMLInNSInstance *inst;
-	if (state->ns_by_id->len <= ns_id)
-		return NULL;
-	if (NULL == (inst = g_ptr_array_index (state->ns_by_id, ns_id)))
-		return NULL;
-	if (strncmp (str, inst->tag, inst->taglen))
+
+	/* If this is the default namespace there will not be an entry in the
+	 * ns_by_id array */
+	if (ns_id >= state->ns_by_id->len ||
+	    NULL == (inst = g_ptr_array_index (state->ns_by_id, ns_id)) ||
+	    0 != strncmp (str, inst->tag, inst->taglen)) {
+		if (NULL != state->default_ns && state->default_ns->ns_id == ns_id)
+			return (NULL == strchr (str, ':')) ? str : NULL;
 		return NULL;
+	}
+
 	return str + inst->taglen;
 }
 
@@ -1055,17 +1072,25 @@ gsf_xml_in_namecmp (GsfXMLIn const *xin, char const *str,
 	GsfXMLInInternal const *state = (GsfXMLInInternal const *)xin;
 	GsfXMLInNSInstance *inst;
 
-	if (state->ns_by_id->len <= ns_id)
-		return FALSE;
-	if (NULL == (inst = g_ptr_array_index (state->ns_by_id, ns_id)))
-		return FALSE;
-	if (strncmp (str, inst->tag, inst->taglen))
+	/* check for default namespace as a likely choice */
+	if (NULL != state->default_ns && state->default_ns->ns_id == ns_id &&
+	    0 == strcmp (name, str))
+		return TRUE;
+
+	if (ns_id >= state->ns_by_id->len ||
+	    NULL == (inst = g_ptr_array_index (state->ns_by_id, ns_id)) ||
+	    0 != strncmp (str, inst->tag, inst->taglen))
 		return FALSE;
 	return 0 == strcmp (name, str + inst->taglen);
 }
 
 /****************************************************************************/
 
+enum {
+	PROP_0,
+	PROP_PRETTY_PRINT
+};
+
 typedef enum {
 	GSF_XML_OUT_NOCONTENT,
 	GSF_XML_OUT_CHILD,
@@ -1081,12 +1106,49 @@ struct _GsfXMLOut {
 	GsfXMLOutState	  state;
 	unsigned   	  indent;
 	gboolean	  needs_header;
+	gboolean	  pretty_print;
 };
 
 typedef struct {
 	GObjectClass  base;
 } GsfXMLOutClass;
 
+static void
+gsf_xml_out_set_property (GObject      *object,
+			  guint         property_id,
+			  GValue const *value,
+			  GParamSpec   *pspec)
+{
+	GsfXMLOut *xml = (GsfXMLOut *)object;
+
+	switch (property_id) {
+	case PROP_PRETTY_PRINT:
+		xml->pretty_print = g_value_get_boolean (value);
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
+	}
+}
+
+static void
+gsf_xml_out_get_property (GObject     *object,
+			  guint        property_id,
+			  GValue      *value,
+			  GParamSpec  *pspec)
+{
+	GsfXMLOut const *xml = (GsfXMLOut const *)object;
+
+	switch (property_id) {
+	case PROP_PRETTY_PRINT:
+		g_value_set_boolean (value, xml->pretty_print);
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
+	}
+}
+
 static void
 gsf_xml_out_finalize (GObject *obj)
 {
@@ -1107,13 +1169,22 @@ gsf_xml_out_init (GObject *obj)
 	xml->indent = 0;
 	xml->needs_header = TRUE;
 	xml->doc_type = NULL;
+	xml->pretty_print = TRUE;
 }
 
 static void
 gsf_xml_out_class_init (GObjectClass *gobject_class)
 {
-	gobject_class->finalize = gsf_xml_out_finalize;
 	parent_class = g_type_class_peek_parent (gobject_class);
+
+	gobject_class->finalize	    = gsf_xml_out_finalize;
+	gobject_class->get_property = gsf_xml_out_get_property;
+	gobject_class->set_property = gsf_xml_out_set_property;
+
+	g_object_class_install_property (gobject_class, PROP_PRETTY_PRINT,
+		 g_param_spec_boolean ("pretty-print", "Pretty print",
+			"Should the output auto-indent elements to make reading easier",
+			TRUE, GSF_PARAM_STATIC | G_PARAM_READWRITE));
 }
 
 GSF_CLASS (GsfXMLOut, gsf_xml_out,
@@ -1162,10 +1233,12 @@ gsf_xml_out_indent (GsfXMLOut *xml)
 		"                                        "
 		"                                        "
 		"                                        ";
-	unsigned i;
-	for (i = xml->indent ; i > (sizeof (spaces)/2) ; i -= sizeof (spaces)/2)
-		gsf_output_write (xml->output, sizeof (spaces) - 1, spaces);
-	gsf_output_write (xml->output, i*2, spaces);
+	if (xml->pretty_print) {
+		unsigned i;
+		for (i = xml->indent ; i > (sizeof (spaces)/2) ; i -= sizeof (spaces)/2)
+			gsf_output_write (xml->output, sizeof (spaces) - 1, spaces);
+		gsf_output_write (xml->output, i*2, spaces);
+	}
 }
 
 /**
@@ -1190,8 +1263,12 @@ gsf_xml_out_start_element (GsfXMLOut *xml, char const *id)
 			gsf_output_puts (xml->output, xml->doc_type);
 		xml->needs_header = FALSE;
 	}
-	if (xml->state == GSF_XML_OUT_NOCONTENT)
-		gsf_output_write (xml->output, 2, ">\n");
+	if (xml->state == GSF_XML_OUT_NOCONTENT) {
+		if (xml->pretty_print)
+			gsf_output_write (xml->output, 2, ">\n");
+		else
+			gsf_output_write (xml->output, 1, ">");
+	}
 
 	gsf_xml_out_indent (xml);
 	gsf_output_printf (xml->output, "<%s", id);
@@ -1222,14 +1299,20 @@ gsf_xml_out_end_element (GsfXMLOut *xml)
 	xml->indent--;
 	switch (xml->state) {
 	case GSF_XML_OUT_NOCONTENT :
-		gsf_output_write (xml->output, 3, "/>\n");
+		if (xml->pretty_print)
+			gsf_output_write (xml->output, 3, "/>\n");
+		else
+			gsf_output_write (xml->output, 2, "/>");
 		break;
 
 	case GSF_XML_OUT_CHILD :
 		gsf_xml_out_indent (xml);
 	/* fall through */
 	case GSF_XML_OUT_CONTENT :
-		gsf_output_printf (xml->output, "</%s>\n", id);
+		if (xml->pretty_print)
+			gsf_output_printf (xml->output, "</%s>\n", id);
+		else
+			gsf_output_printf (xml->output, "</%s>", id);
 	}
 	xml->state = GSF_XML_OUT_CHILD;
 	return id;
@@ -1384,8 +1467,16 @@ gsf_xml_out_add_cstr (GsfXMLOut *xml, char const *id,
 			   (*cur == '\n') || (*cur == '\r') || (*cur == '\t')) {
 			cur++;
 		} else {
+			/*
+			 * This is immensely pathetic, but XML 1.0 does not
+			 * allow certain characters to be encoded.  XML 1.1
+			 * does allow this, but libxml2 does not support it.
+			 */
 			g_warning ("Unknown char 0x%hhx in string", *cur);
-			cur++;
+
+			if (cur != start)
+				gsf_output_write (xml->output, cur-start, start);
+			start = ++cur;
 		}
 	}
 	if (cur != start)
