@@ -43,6 +43,11 @@
 
 static void base64_init (void);
 
+#ifdef G_OS_WIN32
+#include <windows.h>
+G_WIN32_DLLMAIN_FOR_DLL_NAME (static, dll_name)
+#endif
+
 /**
  * gsf_init :
  *
@@ -52,7 +57,16 @@ void
 gsf_init (void)
 {
 #ifdef ENABLE_NLS
+#ifdef G_OS_WIN32
+#undef GNOMELOCALEDIR
+	gchar *prefix = g_win32_get_package_installation_directory (NULL, dll_name);
+	gchar *GNOMELOCALEDIR = g_build_filename (prefix, "lib/locale", NULL);
+	g_free (prefix);
+#endif
 	bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);
+#ifdef G_OS_WIN32
+	g_free (GNOMELOCALEDIR);
+#endif
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 #endif
 
@@ -91,7 +105,7 @@ gsf_mem_dump_full (guint8 const *ptr, size_t len, gsf_off_t offset)
 		g_print ("%8lx | ", (long)(i*16 + offset));
 		for (j = 0;j < 16; j++) {
 			off = j + (i << 4);
-			off<len ? g_print("%2x ", ptr[off]) : g_print("XX ");
+			off<len ? g_print("%02x ", ptr[off]) : g_print("XX ");
 		}
 		g_print ("| ");
 		for (j = 0 ; j < 16 ; j++) {
@@ -476,8 +490,20 @@ base64_init(void)
 	camel_mime_base64_rank['='] = 0;
 }
 
-/* call this when finished encoding everything, to
-   flush off the last little bit */
+/**
+ * gsf_base64_encode_close :
+ * @in : Data to be encoded
+ * @inlen : Length of data to be encoded
+ * @break_lines : Whether to use line breaks
+ * @out : Encoded data.
+ * @state: holds the number of bits that are stored in @save
+ * @save: leftover bits that have not yet been decoded
+ *
+ * This funcion should be called to when finished encoding everything, to
+ * flush off the last little bit.
+ *
+ * Returns :
+ */
 size_t
 gsf_base64_encode_close (guint8 const *in, size_t inlen,
 			 gboolean break_lines, guint8 *out, int *state, unsigned int *save)
@@ -520,11 +546,21 @@ gsf_base64_encode_close (guint8 const *in, size_t inlen,
 	return outptr-out;
 }
 
-/*
-  performs an 'encode step', only encodes blocks of 3 characters to the
-  output at a time, saves left-over state in state and save (initialise to
-  0 on first invocation).
-*/
+/**
+ * gsf_base64_encode_step :
+ * @in : input stream
+ * @len : max length of data to decode
+ * @break_lines : Whether to use line breaks
+ * @out : output stream
+ * @state : holds the number of bits that are stored in @save
+ * @save : leftover bits that have not yet been decoded
+ *
+ * Performs an 'encode step', only encodes blocks of 3 characters from @in into
+ * the output @out at a time, saves left-over state in @state and @save
+ * (initialise to 0 on first invocation).
+ *
+ * Returns : the number of bytes encoded
+ */
 size_t
 gsf_base64_encode_step (guint8 const *in, size_t len,
 			gboolean break_lines, guint8 *out, int *state, unsigned int *save)
@@ -665,6 +701,15 @@ gsf_base64_decode_step (guint8 const *in, size_t len, guint8 *out,
 	return outptr-out;
 }
 
+/**
+ * gsf_base64_encode_simple :
+ * @data : data stream
+ * @len : max length of data to encode
+ *
+ * Encodes data from @data back into @data using base64 encoding.
+ *
+ * Returns : the number of bytes encoded
+ */
 guint8 *
 gsf_base64_encode_simple (guint8 const *data, size_t len)
 {
@@ -683,6 +728,15 @@ gsf_base64_encode_simple (guint8 const *data, size_t len)
 	return out;
 }
 
+/**
+ * gsf_base64_decode_simple :
+ * @data : data stream
+ * @len : max length of data to decode
+ *
+ * Decodes a chunk of base64 encoded data from @data back into @data.
+ *
+ * Returns : the number of bytes converted
+ */
 size_t
 gsf_base64_decode_simple (guint8 *data, size_t len)
 {
