@@ -29,7 +29,7 @@ test (int argc, char *argv[])
 {
 	GsfInput *input;
 	GsfInput *bzip;
-	GError   *err;
+	GError   *err = NULL;
 	int i;
 
 	for (i = 1 ; i < argc ; i++) {
