@@ -30,7 +30,7 @@ test (int argc, char *argv[])
 {
 	GsfInput *input;
 	GsfInput *gzip;
-	GError   *err;
+	GError   *err = NULL;
 	int i;
 
 	for (i = 1 ; i < argc ; i++) {
