@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -30,7 +30,7 @@ test (int argc, char *argv[])
 {
 	GsfInput     	 *input;
 	GsfInputTextline *textline;
-	GError       	 *err;
+	GError       	 *err = NULL;
 	unsigned char *line;
 
 	if (argc < 2) {
