@@ -41,7 +41,7 @@ test (int argc, char *argv[])
 	GsfOutput  *output;
 	GsfOutfile *outfile, *dir1, *dir2;
 	GsfOutput  *ch1, *ch2, *ch3;
-	GError   *err;
+	GError   *err = NULL;
 
 	if (argc != 2) {
 		fprintf (stderr, "Usage : %s outfile\n", argv[0]);
